cleanapi

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// optional cleanapi.EnumOptions enum = 50001;
	E_Enum = &file_cleanapi_cleanapi_proto_extTypes[3]
)

Extension fields to descriptorpb.EnumOptions.

var (
	// optional cleanapi.FieldOptions field = 50001;
	E_Field = &file_cleanapi_cleanapi_proto_extTypes[2]
)

Extension fields to descriptorpb.FieldOptions.

var (
	// optional cleanapi.FileOptions file = 50001;
	E_File = &file_cleanapi_cleanapi_proto_extTypes[0]
)

Extension fields to descriptorpb.FileOptions.

var (
	// optional cleanapi.MessageOptions message = 50001;
	E_Message = &file_cleanapi_cleanapi_proto_extTypes[1]
)

Extension fields to descriptorpb.MessageOptions.

var (
	// optional cleanapi.MethodOptions method = 50001;
	E_Method = &file_cleanapi_cleanapi_proto_extTypes[6]
)

Extension fields to descriptorpb.MethodOptions.

var (
	// optional cleanapi.ServiceOptions service = 50001;
	E_Service = &file_cleanapi_cleanapi_proto_extTypes[5]
)

Extension fields to descriptorpb.ServiceOptions.

var (
	// optional cleanapi.EnumValueOptions value = 50001;
	E_Value = &file_cleanapi_cleanapi_proto_extTypes[4]
)

Extension fields to descriptorpb.EnumValueOptions.

var File_cleanapi_cleanapi_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type EnumOptions added in v0.0.5

type EnumOptions struct {
	// contains filtered or unexported fields
}

func (*EnumOptions) GetPrivate added in v0.0.5

func (x *EnumOptions) GetPrivate() bool

func (*EnumOptions) ProtoMessage added in v0.0.5

func (*EnumOptions) ProtoMessage()

func (*EnumOptions) ProtoReflect added in v0.0.5

func (x *EnumOptions) ProtoReflect() protoreflect.Message

func (*EnumOptions) Reset added in v0.0.5

func (x *EnumOptions) Reset()

func (*EnumOptions) SetPrivate added in v0.0.5

func (x *EnumOptions) SetPrivate(v bool)

func (*EnumOptions) String added in v0.0.5

func (x *EnumOptions) String() string

type EnumOptions_builder added in v0.0.5

type EnumOptions_builder struct {

	// Marks an enum as private, so that it will be excluded from the public API.
	Private bool
	// contains filtered or unexported fields
}

func (EnumOptions_builder) Build added in v0.0.5

func (b0 EnumOptions_builder) Build() *EnumOptions

type EnumValueOptions added in v0.0.5

type EnumValueOptions struct {
	// contains filtered or unexported fields
}

func (*EnumValueOptions) GetPrivate added in v0.0.5

func (x *EnumValueOptions) GetPrivate() bool

func (*EnumValueOptions) ProtoMessage added in v0.0.5

func (*EnumValueOptions) ProtoMessage()

func (*EnumValueOptions) ProtoReflect added in v0.0.5

func (x *EnumValueOptions) ProtoReflect() protoreflect.Message

func (*EnumValueOptions) Reset added in v0.0.5

func (x *EnumValueOptions) Reset()

func (*EnumValueOptions) SetPrivate added in v0.0.5

func (x *EnumValueOptions) SetPrivate(v bool)

func (*EnumValueOptions) String added in v0.0.5

func (x *EnumValueOptions) String() string

type EnumValueOptions_builder added in v0.0.5

type EnumValueOptions_builder struct {

	// Marks an enum value as private, so that it will be excluded from the public API.
	Private bool
	// contains filtered or unexported fields
}

func (EnumValueOptions_builder) Build added in v0.0.5

type FieldOptions added in v0.0.5

type FieldOptions struct {
	// contains filtered or unexported fields
}

func (*FieldOptions) GetPrivate added in v0.0.5

func (x *FieldOptions) GetPrivate() bool

func (*FieldOptions) ProtoMessage added in v0.0.5

func (*FieldOptions) ProtoMessage()

func (*FieldOptions) ProtoReflect added in v0.0.5

func (x *FieldOptions) ProtoReflect() protoreflect.Message

func (*FieldOptions) Reset added in v0.0.5

func (x *FieldOptions) Reset()

func (*FieldOptions) SetPrivate added in v0.0.5

func (x *FieldOptions) SetPrivate(v bool)

func (*FieldOptions) String added in v0.0.5

func (x *FieldOptions) String() string

type FieldOptions_builder added in v0.0.5

type FieldOptions_builder struct {

	// Marks a field as private, so that it will be excluded from the public API.
	Private bool
	// contains filtered or unexported fields
}

func (FieldOptions_builder) Build added in v0.0.5

func (b0 FieldOptions_builder) Build() *FieldOptions

type FileOptions

type FileOptions struct {
	// contains filtered or unexported fields
}

func (*FileOptions) GetPackage

func (x *FileOptions) GetPackage() string

func (*FileOptions) GetPrivate

func (x *FileOptions) GetPrivate() bool

func (*FileOptions) GetRemoveHttpOptions

func (x *FileOptions) GetRemoveHttpOptions() bool

func (*FileOptions) ProtoMessage

func (*FileOptions) ProtoMessage()

func (*FileOptions) ProtoReflect

func (x *FileOptions) ProtoReflect() protoreflect.Message

func (*FileOptions) Reset

func (x *FileOptions) Reset()

func (*FileOptions) SetPackage

func (x *FileOptions) SetPackage(v string)

func (*FileOptions) SetPrivate

func (x *FileOptions) SetPrivate(v bool)

func (*FileOptions) SetRemoveHttpOptions

func (x *FileOptions) SetRemoveHttpOptions(v bool)

func (*FileOptions) String

func (x *FileOptions) String() string

type FileOptions_builder

type FileOptions_builder struct {

	// Marks a file as private, so that it will be excluded from the public API.
	Private bool
	// Indicates that the package name should be replaced by this.
	Package string
	// When true, removes google.api.http annotations used for gRPC-to-REST transcoding.
	RemoveHttpOptions bool
	// contains filtered or unexported fields
}

func (FileOptions_builder) Build

func (b0 FileOptions_builder) Build() *FileOptions

type MessageOptions added in v0.0.5

type MessageOptions struct {
	// contains filtered or unexported fields
}

func (*MessageOptions) GetPrivate added in v0.0.5

func (x *MessageOptions) GetPrivate() bool

func (*MessageOptions) ProtoMessage added in v0.0.5

func (*MessageOptions) ProtoMessage()

func (*MessageOptions) ProtoReflect added in v0.0.5

func (x *MessageOptions) ProtoReflect() protoreflect.Message

func (*MessageOptions) Reset added in v0.0.5

func (x *MessageOptions) Reset()

func (*MessageOptions) SetPrivate added in v0.0.5

func (x *MessageOptions) SetPrivate(v bool)

func (*MessageOptions) String added in v0.0.5

func (x *MessageOptions) String() string

type MessageOptions_builder added in v0.0.5

type MessageOptions_builder struct {

	// Marks a message as private, so that it will be excluded from the public API.
	Private bool
	// contains filtered or unexported fields
}

func (MessageOptions_builder) Build added in v0.0.5

type MethodOptions added in v0.0.5

type MethodOptions struct {
	// contains filtered or unexported fields
}

func (*MethodOptions) GetPrivate added in v0.0.5

func (x *MethodOptions) GetPrivate() bool

func (*MethodOptions) ProtoMessage added in v0.0.5

func (*MethodOptions) ProtoMessage()

func (*MethodOptions) ProtoReflect added in v0.0.5

func (x *MethodOptions) ProtoReflect() protoreflect.Message

func (*MethodOptions) Reset added in v0.0.5

func (x *MethodOptions) Reset()

func (*MethodOptions) SetPrivate added in v0.0.5

func (x *MethodOptions) SetPrivate(v bool)

func (*MethodOptions) String added in v0.0.5

func (x *MethodOptions) String() string

type MethodOptions_builder added in v0.0.5

type MethodOptions_builder struct {

	// Mars a field as private, so that it will be excluded from the public API.
	Private bool
	// contains filtered or unexported fields
}

func (MethodOptions_builder) Build added in v0.0.5

type ServiceOptions added in v0.0.5

type ServiceOptions struct {
	// contains filtered or unexported fields
}

func (*ServiceOptions) GetPrivate added in v0.0.5

func (x *ServiceOptions) GetPrivate() bool

func (*ServiceOptions) ProtoMessage added in v0.0.5

func (*ServiceOptions) ProtoMessage()

func (*ServiceOptions) ProtoReflect added in v0.0.5

func (x *ServiceOptions) ProtoReflect() protoreflect.Message

func (*ServiceOptions) Reset added in v0.0.5

func (x *ServiceOptions) Reset()

func (*ServiceOptions) SetPrivate added in v0.0.5

func (x *ServiceOptions) SetPrivate(v bool)

func (*ServiceOptions) String added in v0.0.5

func (x *ServiceOptions) String() string

type ServiceOptions_builder added in v0.0.5

type ServiceOptions_builder struct {

	// Marks a service as private, so that it will be excluded from the public API.
	Private bool
	// contains filtered or unexported fields
}

func (ServiceOptions_builder) Build added in v0.0.5

Jump to